@@ -2733,7 +2733,7 @@ void Channel::setIdentity(const IdentityPtr identity)
 
 bool Channel::eventFilter(TQObject* watched, TQEvent* e)
 {
-    if((TQT_BASE_OBJECT(watched) == TQT_BASE_OBJECT(nicknameListView)) && (e->type() == TQEvent::Resize) && splittersInitialized && isShown())
+    if(watched == nicknameListView && e->type() == TQEvent::Resize && splittersInitialized && isShown())
     {
         if (!topicSplitterHidden && !channelSplitterHidden)
         {
