@@ -73,7 +73,7 @@ class NickList : public TQPtrList<Nick>
 
 class Channel : public ChatWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
