@@ -13,15 +13,14 @@
 #include "connectionsettings.h"
 #include "serversettings.h"
 #include "servergroupsettings.h"
-#include "config/preferences.h"
 #include "konversationapplication.h"
 #include "konversationmainwindow.h"
 #include "statuspanel.h"
 
 #include <tqregexp.h>
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 
 
 ConnectionManager::ConnectionManager(TQObject* parent) : TQObject(parent)
