@@ -24,7 +24,7 @@ class Highlight;
 
 class Highlight_Config : public Highlight_ConfigUI, public KonviSettingsPage
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
