@@ -25,7 +25,7 @@
 
 class Images : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
