@@ -28,7 +28,7 @@ KonsolePanel::KonsolePanel(TQWidget *p) : ChatWindow( p ), k_part (0)
     k_part = (KParts::ReadOnlyPart *) fact->create(TQT_TQOBJECT(this));
     if (!k_part) return;
 
-    k_part->widget()->setFocusPolicy(TQ_WheelFocus);
+    k_part->widget()->setFocusPolicy(TQWidget::WheelFocus);
     setFocusProxy(k_part->widget());
     k_part->widget()->setFocus();
 
