@@ -34,25 +34,25 @@
 #include <tqsignalmapper.h>
 #include <tqobjectlist.h>
 
-#include <kaccel.h>
-#include <kaccelmanager.h>
+#include <tdeaccel.h>
+#include <tdeaccelmanager.h>
 #include <kstdaction.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kmenubar.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdemenubar.h>
 #include <kkeydialog.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <kedittoolbar.h>
-#include <kpopupmenu.h>
-#include <kwin.h>
-#include <kglobal.h>
+#include <tdepopupmenu.h>
+#include <twin.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
 #include <dcopclient.h>
 #include <scriptmanager.h>
-#include <kabc/addressbook.h>
-#include <kabc/errorhandler.h>
+#include <tdeabc/addressbook.h>
+#include <tdeabc/errorhandler.h>
 
 #include <config.h>
 #ifdef  USE_KNOTIFY
@@ -60,7 +60,7 @@
 #endif
 
 
-KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window", WStyle_ContextHelp | WType_TopLevel | WDestructiveClose)
+KonversationMainWindow::KonversationMainWindow() : TDEMainWindow(0,"main_window", WStyle_ContextHelp | WType_TopLevel | WDestructiveClose)
 {
     m_hasDirtySettings = false;
     m_closeApp = false;
@@ -123,98 +123,98 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
     KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(configureToolbar()), actionCollection());
 
     KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT(openKeyBindings()), actionCollection());
-    KAction *preferencesAction = KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(openPrefsDialog()), actionCollection());
+    TDEAction *preferencesAction = KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(openPrefsDialog()), actionCollection());
 
 #ifdef USE_KNOTIFY // options_configure_notifications
-    KAction *configureNotificationsAction = KStdAction::configureNotifications(TQT_TQOBJECT(this),TQT_SLOT(openNotifications()), actionCollection());
+    TDEAction *configureNotificationsAction = KStdAction::configureNotifications(TQT_TQOBJECT(this),TQT_SLOT(openNotifications()), actionCollection());
 #endif
 
-    KAction* action;
+    TDEAction* action;
 
-    (new KAction(i18n("&Server List..."), "server", KShortcut("F2"), TQT_TQOBJECT(this), TQT_SLOT(openServerList()),
+    (new TDEAction(i18n("&Server List..."), "server", TDEShortcut("F2"), TQT_TQOBJECT(this), TQT_SLOT(openServerList()),
         actionCollection(), "open_server_list"))->setToolTip(i18n("Manage networks and servers"));
-    (new KAction(i18n("Quick &Connect..."), "connect_creating", KShortcut("F7"), TQT_TQOBJECT(this), TQT_SLOT(openQuickConnectDialog()),
+    (new TDEAction(i18n("Quick &Connect..."), "connect_creating", TDEShortcut("F7"), TQT_TQOBJECT(this), TQT_SLOT(openQuickConnectDialog()),
         actionCollection(), "quick_connect_dialog"))->setToolTip(i18n("Type in the address of a new IRC server to connect to"));
 
-    action = new KAction(i18n("&Reconnect"), "connect_creating", 0, m_viewContainer, TQT_SLOT(reconnectFrontServer()), actionCollection(), "reconnect_server");
+    action = new TDEAction(i18n("&Reconnect"), "connect_creating", 0, m_viewContainer, TQT_SLOT(reconnectFrontServer()), actionCollection(), "reconnect_server");
     action->setEnabled(false);
     action->setToolTip(i18n("Reconnect to the current server."));
 
-    action = new KAction(i18n("&Disconnect"), "connect_no", 0, m_viewContainer, TQT_SLOT(disconnectFrontServer()), actionCollection(), "disconnect_server");
+    action = new TDEAction(i18n("&Disconnect"), "connect_no", 0, m_viewContainer, TQT_SLOT(disconnectFrontServer()), actionCollection(), "disconnect_server");
     action->setEnabled(false);
     action->setToolTip(i18n("Disconnect from the current server."));
 
-    (new KAction(i18n("&Identities..."), "identity", KShortcut("F8"), TQT_TQOBJECT(this), TQT_SLOT(openIdentitiesDialog()),
+    (new TDEAction(i18n("&Identities..."), "identity", TDEShortcut("F8"), TQT_TQOBJECT(this), TQT_SLOT(openIdentitiesDialog()),
         actionCollection(), "identities_dialog"))->setToolTip(i18n("Manage your nick, away and other identity settings"));
 
-    new KToggleAction(i18n("&Watched Nicks Online"), "kontact_contacts", KShortcut("F4"), m_viewContainer, TQT_SLOT(openNicksOnlinePanel()), actionCollection(), "open_nicksonline_window");
-    new KToggleAction(i18n("&DCC Status"), "2rightarrow", KShortcut("F9"), m_viewContainer, TQT_SLOT(toggleDccPanel()), actionCollection(), "open_dccstatus_window");
-    action = new KAction(i18n("&Open Logfile"), "history", KShortcut("Ctrl+O"), m_viewContainer, TQT_SLOT(openLogFile()), actionCollection(), "open_logfile");
+    new TDEToggleAction(i18n("&Watched Nicks Online"), "kontact_contacts", TDEShortcut("F4"), m_viewContainer, TQT_SLOT(openNicksOnlinePanel()), actionCollection(), "open_nicksonline_window");
+    new TDEToggleAction(i18n("&DCC Status"), "2rightarrow", TDEShortcut("F9"), m_viewContainer, TQT_SLOT(toggleDccPanel()), actionCollection(), "open_dccstatus_window");
+    action = new TDEAction(i18n("&Open Logfile"), "history", TDEShortcut("Ctrl+O"), m_viewContainer, TQT_SLOT(openLogFile()), actionCollection(), "open_logfile");
     action->setEnabled(false);
     action->setToolTip(i18n("Open the known history for this channel in a new tab"));
 
-    action = new KAction(i18n("&Channel Settings..."), "edit", m_viewContainer, TQT_SLOT(openChannelSettings()), actionCollection(), "channel_settings");
+    action = new TDEAction(i18n("&Channel Settings..."), "edit", m_viewContainer, TQT_SLOT(openChannelSettings()), actionCollection(), "channel_settings");
     action->setEnabled(false);
     action->setToolTip(i18n("Open the channel settings dialog for this tab"));
 
-    KToggleAction* channelListAction = new KToggleAction(i18n("Channel &List"), "view_text", KShortcut("F5"), m_viewContainer, TQT_SLOT(openChannelList()), actionCollection(), "open_channel_list");
+    TDEToggleAction* channelListAction = new TDEToggleAction(i18n("Channel &List"), "view_text", TDEShortcut("F5"), m_viewContainer, TQT_SLOT(openChannelList()), actionCollection(), "open_channel_list");
     channelListAction->setEnabled(false);
     channelListAction->setToolTip(i18n("Show a list of all the known channels on this server"));
 
-    action = new KToggleAction(i18n("&URL Catcher"), "enhanced_browsing", KShortcut("F6"), m_viewContainer, TQT_SLOT(addUrlCatcher()), actionCollection(), "open_url_catcher");
+    action = new TDEToggleAction(i18n("&URL Catcher"), "enhanced_browsing", TDEShortcut("F6"), m_viewContainer, TQT_SLOT(addUrlCatcher()), actionCollection(), "open_url_catcher");
     action->setToolTip(i18n("List all URLs that have been mentioned recently in a new tab"));
 
     if (kapp->authorize("shell_access"))
     {
-        action = new KAction(i18n("New &Konsole"), "openterm", 0, m_viewContainer, TQT_SLOT(addKonsolePanel()), actionCollection(), "open_konsole");
+        action = new TDEAction(i18n("New &Konsole"), "openterm", 0, m_viewContainer, TQT_SLOT(addKonsolePanel()), actionCollection(), "open_konsole");
         action->setToolTip(i18n("Open a terminal in a new tab"));
     }
 
     // Actions to navigate through the different pages
-    KShortcut nextShortcut = KStdAccel::tabNext();
+    TDEShortcut nextShortcut = TDEStdAccel::tabNext();
     nextShortcut.setSeq(1, KKeySequence("Alt+Right"));
-    KShortcut prevShortcut = KStdAccel::tabPrev();
+    TDEShortcut prevShortcut = TDEStdAccel::tabPrev();
     prevShortcut.setSeq(1, KKeySequence("Alt+Left"));
-    action = new KAction(i18n("&Next Tab"), TQApplication::reverseLayout() ? "previous" : "next",
+    action = new TDEAction(i18n("&Next Tab"), TQApplication::reverseLayout() ? "go-previous" : "go-next",
         TQApplication::reverseLayout() ? prevShortcut : nextShortcut,
         m_viewContainer, TQT_SLOT(showNextView()), actionCollection(), "next_tab");
     action->setEnabled(false);
-    action = new KAction(i18n("&Previous Tab"), TQApplication::reverseLayout() ? "next" : "previous",
+    action = new TDEAction(i18n("&Previous Tab"), TQApplication::reverseLayout() ? "go-next" : "go-previous",
         TQApplication::reverseLayout() ? nextShortcut : prevShortcut,
         m_viewContainer, TQT_SLOT(showPreviousView()),actionCollection(),"previous_tab");
     action->setEnabled(false);
-    action = new KAction(i18n("Close &Tab"),"tab_remove",KShortcut("Ctrl+w"), m_viewContainer, TQT_SLOT(closeCurrentView()),actionCollection(),"close_tab");
+    action = new TDEAction(i18n("Close &Tab"),"tab_remove",TDEShortcut("Ctrl+w"), m_viewContainer, TQT_SLOT(closeCurrentView()),actionCollection(),"close_tab");
     action->setEnabled(false);
-    action = new KAction(i18n("Next Active Tab"), 0, KShortcut("Ctrl+Alt+Space"), m_viewContainer, TQT_SLOT(showNextActiveView()),
+    action = new TDEAction(i18n("Next Active Tab"), 0, TDEShortcut("Ctrl+Alt+Space"), m_viewContainer, TQT_SLOT(showNextActiveView()),
                          actionCollection(), "next_active_tab");
     action->setEnabled(false);
 
     if (Preferences::tabPlacement()==PreferencesBase::Left)
     {
-        action = new KAction(i18n("Move Tab Up"), "1uparrow", KShortcut("Alt+Shift+Left"),
+        action = new TDEAction(i18n("Move Tab Up"), "1uparrow", TDEShortcut("Alt+Shift+Left"),
             m_viewContainer, TQT_SLOT(moveViewLeft()), actionCollection(), "move_tab_left");
         action->setEnabled(false);
         action->setToolTip("Move this tab");
-        action = new KAction(i18n("Move Tab Down"), "1downarrow", KShortcut("Alt+Shift+Right"),
+        action = new TDEAction(i18n("Move Tab Down"), "1downarrow", TDEShortcut("Alt+Shift+Right"),
             m_viewContainer, TQT_SLOT(moveViewRight()), actionCollection(), "move_tab_right");
         action->setEnabled(false);
         action->setToolTip("Move this tab");
     }
     else
     {
-        KAction* action2;
+        TDEAction* action2;
         if (TQApplication::reverseLayout())
         {
-            action2 = new KAction(i18n("Move Tab Right"), "1rightarrow", KShortcut("Alt+Shift+Right"),
+            action2 = new TDEAction(i18n("Move Tab Right"), "1rightarrow", TDEShortcut("Alt+Shift+Right"),
                           m_viewContainer, TQT_SLOT(moveViewLeft()), actionCollection(), "move_tab_left");
-            action  = new KAction(i18n("Move Tab Left"), "1leftarrow", KShortcut("Alt+Shift+Left"),
+            action  = new TDEAction(i18n("Move Tab Left"), "1leftarrow", TDEShortcut("Alt+Shift+Left"),
                           m_viewContainer, TQT_SLOT(moveViewRight()), actionCollection(), "move_tab_right");
         }
         else
         {
-            action  = new KAction(i18n("Move Tab Left"), "1leftarrow", KShortcut("Alt+Shift+Left"),
+            action  = new TDEAction(i18n("Move Tab Left"), "1leftarrow", TDEShortcut("Alt+Shift+Left"),
                           m_viewContainer, TQT_SLOT(moveViewLeft()), actionCollection(), "move_tab_left");
-                action2 = new KAction(i18n("Move Tab Right"), "1rightarrow", KShortcut("Alt+Shift+Right"),
+                action2 = new TDEAction(i18n("Move Tab Right"), "1rightarrow", TDEShortcut("Alt+Shift+Right"),
                           m_viewContainer, TQT_SLOT(moveViewRight()), actionCollection(), "move_tab_right");
         }
 
@@ -224,16 +224,16 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
         action2->setToolTip("Move this tab");
     }
 
-    action = new KAction(i18n("Rejoin Channel"), 0, m_viewContainer, TQT_SLOT(rejoinChannel()), actionCollection(), "rejoin_channel");
+    action = new TDEAction(i18n("Rejoin Channel"), 0, m_viewContainer, TQT_SLOT(rejoinChannel()), actionCollection(), "rejoin_channel");
     action->setEnabled(false);
 
-    action = new KToggleAction(i18n("Enable Notifications"), 0, 0, m_viewContainer, TQT_SLOT(toggleViewNotifications()), actionCollection(), "tab_notifications");
+    action = new TDEToggleAction(i18n("Enable Notifications"), 0, 0, m_viewContainer, TQT_SLOT(toggleViewNotifications()), actionCollection(), "tab_notifications");
     action->setEnabled(false);
 
-    action = new KToggleAction(i18n("Join on Connect"), 0, 0, m_viewContainer, TQT_SLOT(toggleAutoJoin()), actionCollection(), "tab_autojoin");
+    action = new TDEToggleAction(i18n("Join on Connect"), 0, 0, m_viewContainer, TQT_SLOT(toggleAutoJoin()), actionCollection(), "tab_autojoin");
     action->setEnabled(false);
 
-    KSelectAction* selectAction = new KSelectAction(i18n("Set Encoding"), "charset", 0, actionCollection(), "tab_encoding");
+    TDESelectAction* selectAction = new TDESelectAction(i18n("Set Encoding"), "charset", 0, actionCollection(), "tab_encoding");
     selectAction->setEditable(false);
     TQStringList encodingDescs = Konversation::IRCCharsets::self()->availableEncodingDescriptiveNames();
     encodingDescs.prepend(i18n("Default"));
@@ -246,26 +246,26 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
 
     for (uint i = 1; i <= 10; ++i)
     {
-        KAction* tabSelectionAction = new KAction(i18n("Go to Tab %1").arg(i), 0, KShortcut(TQString("Alt+%1").arg(i%10)),
+        TDEAction* tabSelectionAction = new TDEAction(i18n("Go to Tab %1").arg(i), 0, TDEShortcut(TQString("Alt+%1").arg(i%10)),
             tabSelectionMapper, TQT_SLOT(map()), actionCollection(), TQString("go_to_tab_%1").arg(i).local8Bit());
         tabSelectionMapper->setMapping( tabSelectionAction, i-1);
     }
 
-    action = new KAction(i18n("Clear &Marker Lines"), 0, KShortcut("CTRL+SHIFT+R"), m_viewContainer, TQT_SLOT(clearViewLines()),actionCollection(),"clear_lines");
+    action = new TDEAction(i18n("Clear &Marker Lines"), 0, TDEShortcut("CTRL+SHIFT+R"), m_viewContainer, TQT_SLOT(clearViewLines()),actionCollection(),"clear_lines");
     action->setToolTip(i18n("Clear marker lines in the current tab"));
     action->setEnabled(false);
-    action = new KAction(i18n("&Clear Window"), 0, KShortcut("Ctrl+L"), m_viewContainer, TQT_SLOT(clearView()),actionCollection(),"clear_window");
+    action = new TDEAction(i18n("&Clear Window"), 0, TDEShortcut("Ctrl+L"), m_viewContainer, TQT_SLOT(clearView()),actionCollection(),"clear_window");
     action->setToolTip(i18n("Clear the contents of the current tab"));
     action->setEnabled(false);
-    action = new KAction(i18n("Clear &All Windows"),0,KShortcut("CTRL+SHIFT+L"), m_viewContainer, TQT_SLOT(clearAllViews()),actionCollection(),"clear_tabs");
+    action = new TDEAction(i18n("Clear &All Windows"),0,TDEShortcut("CTRL+SHIFT+L"), m_viewContainer, TQT_SLOT(clearAllViews()),actionCollection(),"clear_tabs");
     action->setToolTip(i18n("Clear the contents of all open tabs"));
     action->setEnabled(false);
 
-    KToggleAction* awayAction = new KToggleAction(i18n("Global Away"), KShortcut("Ctrl+Shift+A"), actionCollection(), "toggle_away");
+    TDEToggleAction* awayAction = new TDEToggleAction(i18n("Global Away"), TDEShortcut("Ctrl+Shift+A"), actionCollection(), "toggle_away");
     connect(awayAction, TQT_SIGNAL(toggled(bool)), static_cast<KonversationApplication*>(kapp)->getAwayManager(), TQT_SLOT(toggleGlobalAway(bool)));
     awayAction->setEnabled(false);
 
-    action = new KAction(i18n("&Join Channel..."), "add", KShortcut("Ctrl+J"), m_viewContainer, TQT_SLOT(showJoinChannelDialog()), actionCollection(), "join_channel");
+    action = new TDEAction(i18n("&Join Channel..."), "add", TDEShortcut("Ctrl+J"), m_viewContainer, TQT_SLOT(showJoinChannelDialog()), actionCollection(), "join_channel");
     action->setEnabled(false);
     action->setToolTip("Join a new channel on this server");
 
@@ -276,21 +276,21 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
     action = KStdAction::findPrev(m_viewContainer, TQT_SLOT(findPrevText()), actionCollection());
     action->setEnabled(false);
 
-    action = new KAction(i18n("&IRC Color..."), "colorize", CTRL+Key_K, m_viewContainer, TQT_SLOT(insertIRCColor()), actionCollection(), "irc_colors");
+    action = new TDEAction(i18n("&IRC Color..."), "colorize", CTRL+Key_K, m_viewContainer, TQT_SLOT(insertIRCColor()), actionCollection(), "irc_colors");
     action->setToolTip(i18n("Set the color of your current IRC message"));
     action->setEnabled(false);
-    action = new KAction(i18n("&Marker Line"), 0,  KShortcut("Ctrl+R") , m_viewContainer, TQT_SLOT(insertMarkerLine()), actionCollection(), "insert_marker_line");
+    action = new TDEAction(i18n("&Marker Line"), 0,  TDEShortcut("Ctrl+R") , m_viewContainer, TQT_SLOT(insertMarkerLine()), actionCollection(), "insert_marker_line");
     action->setToolTip(i18n("Insert a horizontal line into the current tab that only you can see"));
     action->setEnabled(false);
-    action = new KAction(i18n("Special &Character..."), "char", KShortcut("Alt+Shift+C"), m_viewContainer, TQT_SLOT(insertCharacter()), actionCollection(), "insert_character");
+    action = new TDEAction(i18n("Special &Character..."), "char", TDEShortcut("Alt+Shift+C"), m_viewContainer, TQT_SLOT(insertCharacter()), actionCollection(), "insert_character");
     action->setToolTip(i18n("Insert any character into your current IRC message"));
     action->setEnabled(false);
 
-    action = new KAction(i18n("Close &All Open Queries"), 0, KShortcut("F11"), m_viewContainer, TQT_SLOT(closeQueries()), actionCollection(), "close_queries");
+    action = new TDEAction(i18n("Close &All Open Queries"), 0, TDEShortcut("F11"), m_viewContainer, TQT_SLOT(closeQueries()), actionCollection(), "close_queries");
     action->setEnabled(false);
 
-    KToggleAction* toggleChannelNickListsAction = new KToggleAction(i18n("Hide Nicklist"), 0,
-        KShortcut("Ctrl+H"), m_viewContainer, TQT_SLOT(toggleChannelNicklists()), actionCollection(), "hide_nicknamelist");
+    TDEToggleAction* toggleChannelNickListsAction = new TDEToggleAction(i18n("Hide Nicklist"), 0,
+        TDEShortcut("Ctrl+H"), m_viewContainer, TQT_SLOT(toggleChannelNicklists()), actionCollection(), "hide_nicknamelist");
     if (!Preferences::showNickList())
         toggleChannelNickListsAction->setChecked(true);
 
@@ -299,7 +299,7 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
     connect(TQT_TQOBJECT(this), TQT_SIGNAL(endNotification()), m_trayIcon, TQT_SLOT(endNotification()));
     connect(KonversationApplication::instance(), TQT_SIGNAL(iconChanged(int)), m_trayIcon, TQT_SLOT(updateAppearance()));
     connect(m_trayIcon, TQT_SIGNAL(quitSelected()), TQT_TQOBJECT(this), TQT_SLOT(quitProgram()));
-    KPopupMenu *trayMenu = m_trayIcon->contextMenu();
+    TDEPopupMenu *trayMenu = m_trayIcon->contextMenu();
     #ifdef USE_KNOTIFY
     configureNotificationsAction->plug(trayMenu);
     #endif
@@ -322,7 +322,7 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
     m_bookmarkHandler = new KonviBookmarkHandler(this);
 
     // set up KABC with a nice gui error dialog
-    KABC::GuiErrorHandler *m_guiErrorHandler = new KABC::GuiErrorHandler(this);
+    TDEABC::GuiErrorHandler *m_guiErrorHandler = new TDEABC::GuiErrorHandler(this);
     kapp->dcopClient()->setAcceptCalls( false );
     Konversation::Addressbook::self()->getAddressBook()->setErrorHandler(m_guiErrorHandler);
     kapp->dcopClient()->setAcceptCalls( true );
@@ -413,21 +413,21 @@ void KonversationMainWindow::hideEvent(TQHideEvent *e)
 
     m_statusBar->clearMainLabelTempText();
 
-    KMainWindow::hideEvent(e);
+    TDEMainWindow::hideEvent(e);
 }
 
 void KonversationMainWindow::showEvent(TQShowEvent *e)
 {
     emit cancelRememberLine();
 
-    KMainWindow::showEvent(e);
+    TDEMainWindow::showEvent(e);
 }
 
 void KonversationMainWindow::leaveEvent(TQEvent* e)
 {
     m_statusBar->clearMainLabelTempText();
 
-    KMainWindow::leaveEvent(e);
+    TDEMainWindow::leaveEvent(e);
 }
 
 bool KonversationMainWindow::event(TQEvent* e)
@@ -445,7 +445,7 @@ bool KonversationMainWindow::event(TQEvent* e)
             emit triggerRememberLine();
     }
 
-    return KMainWindow::event(e);
+    return TDEMainWindow::event(e);
 }
 
 void KonversationMainWindow::settingsChangedSlot()
@@ -498,7 +498,7 @@ void KonversationMainWindow::toggleMenubar(bool dontShowWarning)
 
 int KonversationMainWindow::configureToolbar()
 {
-    saveMainWindowSettings(KGlobal::config());
+    saveMainWindowSettings(TDEGlobal::config());
     KEditToolbar dlg(actionCollection(), xmlFile(), true, this);
     connect(&dlg, TQT_SIGNAL(newToolbarConfig()), TQT_SLOT(saveToolbarConfig()));
     return dlg.exec();
@@ -507,7 +507,7 @@ int KonversationMainWindow::configureToolbar()
 void KonversationMainWindow::saveToolbarConfig()
 {
     createGUI(xmlFile(), false);
-    applyMainWindowSettings(KGlobal::config());
+    applyMainWindowSettings(TDEGlobal::config());
 }
 
 void KonversationMainWindow::focusAndShowErrorMessage(const TQString &errorMsg)
