@@ -22,7 +22,7 @@
 #include <tqpoint.h>
 #include <tqstring.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 
 
 class NicksOnline;
