@@ -63,8 +63,8 @@ LogfileReader::LogfileReader(TQWidget* parent, const TQString& log) : ChatWindow
 
     updateView();
     resize(Preferences::logfileReaderSize());
-    ircBox->ircView()->setFocusPolicy(TQ_StrongFocus);
-    setFocusPolicy(TQ_StrongFocus);
+    ircBox->ircView()->setFocusPolicy(TQWidget::StrongFocus);
+    setFocusPolicy(TQWidget::StrongFocus);
     setFocusProxy(ircBox->ircView());
 
     connect(getTextView(), TQT_SIGNAL(gotFocus()), getTextView(), TQT_SLOT(setFocus()));
