@@ -33,7 +33,7 @@ class ChatWindow;
 
 class NicksOnline : public ChatWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
