@@ -34,7 +34,7 @@ namespace Konversation {
 
 class Query : public ChatWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
