@@ -22,7 +22,7 @@ class TQDragObject;
 
 class ServerListView : public TDEListView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
