@@ -41,7 +41,7 @@ namespace Konversation
         : KActiveLabel(parent, name)
     {
         setWrapPolicy(TQTextEdit::AtWordOrDocumentBoundary);
-        setFocusPolicy(TQ_ClickFocus);
+        setFocusPolicy(TQWidget::ClickFocus);
 
         m_isOnChannel = false;
         m_copyUrlMenu = false;
